.. testkraut documentation master file, created by
   sphinx-quickstart on Tue Jun 12 17:08:44 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to testkraut's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   design
   tags
   fingerprints

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

